#!/bin/sh
# Compile les CSS à partir de la racine
#set -x
#------------------------------------------------------------------
# Fonctions
#------------------------------------------------------------------
usage () {
clear
echo "Compilation de fichiers CSS (@import url…)"
echo "Version 1.0, Christopher Compagnon"
echo
echo "Usage :"
echo "-s : (source) source"	
echo "-o : (output) cible"	
}


compile () {
ROOT_DIR="${1}"
CSS_FILE="$(basename ${2})"
CSS_DIR="$(dirname ${2})"

cd ${ROOT_DIR}
[ "${CSS_DIR}" != "." ] && cd ${CSS_DIR}

echo "\n\n/*\n==============================" >> ${WORK_FILE}
echo "==== Import de ${CSS_FILE} ====" >> ${WORK_FILE}
echo "==============================\n*/\n\n" >> ${WORK_FILE}

cat ${CSS_FILE} | grep -v "^@import url" >> ${WORK_FILE}
cat ${CSS_FILE} | grep "^@import url" | sed 's/@import url("\(.*\)").*/\1/g' | while read css_import
do
[ ! -f ${css_import} ] && echo "Fichier ${css_import} non trouvé"

if [ "$(dirname ${css_import})" != "." ]
then
compile "${ROOT_DIR}" "${css_import}"
else
compile "$(pwd)" "${css_import}"
fi 
done
	
}
#------------------------------------------------------------------
# Variables
#------------------------------------------------------------------

#------------------------------------------------------------------
# Programme
#------------------------------------------------------------------
clear



# Gestion des options
while getopts ":s:o:" option 
do 
case $option in 

o)
TGT_FILE=${OPTARG}
;;

s)
SRC_FILE=${OPTARG}
;;  

\?) 
usage
exit 0
;;

*)
usage
exit 1
;;

esac
done

# Contrôles
[ ! -f ${SRC_FILE} ] && echo "Le fichier ${SRC_FILE} est introuvable" && exit 1

# Variables
CSS_FILE="$(basename ${SRC_FILE})"
CSS_DIR="$(dirname ${SRC_FILE})"
WORK_FILE="${TGT_FILE}.tmp"

# Préparation
[ -f ${WORK_FILE} ] && rm -f ${WORK_FILE}
[ -f ${TGT_FILE} ] && rm -f ${TGT_FILE}

# compilation
echo "Compilation de ${CSS_FILE} …"
compile "${CSS_DIR}" "${CSS_FILE}"

# Clean code
echo "/*\n==============================" > ${TGT_FILE}
echo "CSS compilés par csscompiler" >> ${TGT_FILE}
echo "v 1.0" >> ${TGT_FILE}
echo "==============================\n*/\n" >> ${TGT_FILE}
cat ${WORK_FILE} | grep "@charset" | sort | uniq >> ${TGT_FILE}
cat ${WORK_FILE} | grep "@namespace" | sort | uniq >> ${TGT_FILE}
cat ${WORK_FILE} | grep -v "@namespace" | grep -v "@charset" >> ${TGT_FILE}

echo "Compilation achevée"

# Clean files
[ -f ${WORK_FILE} ] && rm -f ${WORK_FILE}

#------------------------------------------------------------------
exit 0
